# Installation instructions

1) Add your `client id`, `client secret` and `site_codes` to the `configuration.json` file. `site_codes` is an array, so
   you can use several Kameleoon site codes. Parameter **redirection_mode** and all **import_condition_urls** are optionals.
Optional parameter **redirection_mode** makes it possible to use a different mode of redirection for Nginx. Default is (**rewrite ... last**) whereas if
parameter is equals to "HTTP_302", a temporary redirection will be made from Nginx (using **rewrite ... redirect**).
About **import_condition_urls** optional parameters, they are used to configure importation of a list of URLs from another server,
when URL of condition is equals to **dynamicPages**.

    ```json
    {
        "client_id": "YOUR_CLIENT_ID",
        "client_secret": "YOUR_CLIENT_SECRET",
        "site_codes": ["YOUR_SITE_CODE"],
        "api_url": "https://api.kameleoon.com",
        "nginxConfigurationFile": "/etc/nginx/modules/00-kameleoon.conf",
        "redirection_mode": "REWRITE",
        "import_condition_urls": false,
        "import_condition_urls_server_url": "YOUR_SERVER_WITH_URLS",
        "import_condition_urls_server_client_id": "YOUR_SERVER_ID",
        "import_condition_urls_server_client_secret": "YOUR_SERVER_SECRET"
    }
    ```
3) Then, depending on weather you install it manually or from Docker image:

## Manual installation

1) To make sure that the module can run, PCRE library is required
2) Add module and configuration
    ```
   cp configuration.json /etc/kameleoon
   cp files/nginx_conf_generator.py /opt/bin/kameleoon/
   cp files/ngx_kameleoon_module.so /etc/nginx/modules
   cp files/kameleoon-server.conf /etc/nginx/conf.d
   cp files/nginx.conf /etc/nginx
    ```

3) Make sure you have Python installed and its required libraries (see **requirements.txt**)
4) Set-up cron job
    ```
    cp files/kameleoon-cron /etc/cron.d
    chmod 0644 /etc/cron.d/kameleoon-cron
    crontab /etc/cron.d/kameleoon-cron
    touch /var/log/cron.log
    ```

## Docker image for Kameleoon Nginx Module

1) Build the Docker image with the command `docker build .`.

## Further configuration (optional)

* You can configure your Nginx server context in the file `kameleoon-server.conf`.
  Do not remove this instruction `include /etc/nginx/modules/00-kameleoon.conf;`.
    * You can enable/disable the module with this option: `kameleoon_module on;`.
    * You can return targeted experiments as a list in a header with this option: `kameleoon_experiments_header on;`.
    * You can choose the domain of the cookie with this option: `kameleoon_domain_cookie ".my-domain.com";`.
      By default, without the option the module does not add any domain to the kameleoon cookie, you can also use a
      variable.

* You can configure your Nginx location context in the file `kameleoon-server.conf`.
    * You can ignore the module with this option: `kameleoon_ignore true;`.
      By default, the option is set to false, therefore is will not ignore the kameleoon module, you can also use a
      variable.

* You can edit the main Nginx configuration in the file `nginx.conf`.
  Do not remove the instruction `load_module /etc/nginx/modules/ngx_kameleoon_module.so;` in the main context otherwise
  the module will not load.

* You can change the interval of time the cron job is executed in the file `kameleoon-cron`.
